<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
<context>
    <name>osd::DisPlayModeApplet</name>
    <message>
        <location filename="../displaymodeapplet.cpp" line="151"/>
        <source>Duplicate</source>
        <translation>复制</translation>
    </message>
    <message>
        <location filename="../displaymodeapplet.cpp" line="152"/>
        <source>Extend</source>
        <translation>扩展</translation>
    </message>
    <message>
        <location filename="../displaymodeapplet.cpp" line="157"/>
        <source>Only on %1</source>
        <translation>仅</translation>
    </message>
</context>
</TS>